elephant.spike\_train\_dissimilarity.victor\_purpura\_distance
==============================================================

.. currentmodule:: elephant.spike_train_dissimilarity

.. autofunction:: victor_purpura_distance